#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pureMD5
version:              2.1.3
visibility:           public
id:                   pureMD5-2.1.3-3d85SCd5b2Q1zbasIMLvI7
key:                  pureMD5-2.1.3-3d85SCd5b2Q1zbasIMLvI7
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.

description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.

category:             Data, Cryptography
abi:                  003ab15d749e94b7f5a8441d2bbf3c0f
exposed:              True
exposed-modules:      Data.Digest.Pure.MD5
import-dirs:          /usr/lib/ghc-8.10.5/site-local/pureMD5-2.1.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/pureMD5-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/pureMD5-2.1.3
hs-libraries:         HSpureMD5-2.1.3-3d85SCd5b2Q1zbasIMLvI7
depends:
    base-4.14.2.0 binary-0.8.8.0 bytestring-0.10.12.0
    cereal-0.5.8.1-4r85zOZIbEW4fo8WFnBuTl
    crypto-api-0.13.3-8kK7ehsYBxqIrjHyd9ebTX
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV

haddock-interfaces:   /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html:         /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

